import { hasDependency } from '../../util/plugin.js';
import { toEntryPattern, toProductionEntryPattern } from '../../util/protocols.js';
const NAME = 'Next.js';
const ENABLERS = ['next'];
const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
const ENTRY_FILE_PATTERNS = ['next.config.{js,ts,cjs,mjs}'];
const productionEntryFilePatternsWithoutSrc = [
    '{instrumentation,middleware}.{js,ts}',
    'app/global-error.{js,jsx,ts,tsx}',
    'app/**/{error,layout,loading,not-found,page,template}.{js,jsx,ts,tsx}',
    'app/**/{route,default}.{js,ts}',
    'app/{manifest,sitemap,robots}.{js,ts}',
    'app/**/{icon,apple-icon}.{js,jsx,ts,tsx}',
    'app/**/{opengraph,twitter}-image.{js,jsx,ts,tsx}',
    'pages/**/*.{js,jsx,ts,tsx}',
];
const PRODUCTION_ENTRY_FILE_PATTERNS = [
    ...productionEntryFilePatternsWithoutSrc,
    ...productionEntryFilePatternsWithoutSrc.map(pattern => `src/${pattern}`),
];
const findDependencies = async (configFilePath, options) => {
    const { config } = options;
    return config.entry
        ? config.entry.map(toProductionEntryPattern)
        : [...ENTRY_FILE_PATTERNS.map(toEntryPattern), ...PRODUCTION_ENTRY_FILE_PATTERNS.map(toProductionEntryPattern)];
};
export default {
    NAME,
    ENABLERS,
    isEnabled,
    ENTRY_FILE_PATTERNS,
    PRODUCTION_ENTRY_FILE_PATTERNS,
    findDependencies,
};
